@@ -8,19 +8,18 @@ from collections.abc import Callable, Iterable, Mapping
 from typing import Any, Concatenate, Generic, ParamSpec, TypeVar
 from urllib.parse import urlparse
 
-from ..typing import MISSING, PRESENT, BlobTypes, MissingType
+from ..typing import MISSING, PRESENT, BlobTypes, MissingType, frid_type_size
 from ..typing import FridTypeName, FridTypeSize, FridValue, FridArray, FridBeing, StrKeyMap
-from ..autils import AsyncReentrantLock
+from ..aio import CountedAsyncLock
 from ..chrono import parse_datetime, strfr_datetime, datetime, timezone
 from ..guards import is_frid_array, is_frid_skmap
-from ..helper import frid_merge, frid_type_size
-from ..strops import escape_control_chars, revive_control_chars
-from ..dumper import dump_frid_str
-from ..loader import load_frid_str
+from .._basic import frid_mingle
+from ..lib.texts import str_encode_nonprints, str_decode_nonprints
+from .._dumps import dump_frid_str
+from .._loads import load_frid_str
 from .store import AsyncStore, ValueStore
 from .utils import KeySearch, VSPutFlag, VStoreKey, VStoreSel, frid_delete, frid_select, list_concat, match_key
 
-_T = TypeVar('_T')
 _E = TypeVar('_E')   # The encoding type
 _P = ParamSpec('_P')
 
@@ -71,7 +70,7 @@ class _SimpleBaseStore(Generic[_E]):
             return key
         if isinstance(key, tuple):
             # Using the DEL key to escape
-            return '\t'.join(escape_control_chars(str(k), '\x7f') for k in key)
+            return '\t'.join(str_encode_nonprints(str(k), '\x7f') for k in key)
         raise ValueError(f"Invalid key type {type(key)}")
 
     def _get_sel(self, val: _E, sel: VStoreSel, /) -> FridValue|MissingType:
@@ -84,7 +83,7 @@ class _SimpleBaseStore(Generic[_E]):
         old_data = old if isinstance(old, FridBeing) else self._decode(old)
         assert old_data is not PRESENT
         # TODO: frid_merge() to accept more merge flags
-        new_data = frid_merge(old_data, new, depth=0)
+        new_data = frid_mingle(old_data, new, depth=0)
         if new_data is old_data:
             return PRESENT
         return self._encode(new_data)
@@ -190,7 +189,7 @@ class MemoryValueStore(SimpleValueStore[FridValue]):
     class StoreMeta:
         store: dict[str,FridValue] = field(default_factory=dict)
         tlock: threading.RLock = field(default_factory=threading.RLock)
-        alock: asyncio.Lock = field(default_factory=AsyncReentrantLock)
+        alock: asyncio.Lock = field(default_factory=CountedAsyncLock)
 
     DataSpaceType = dict[tuple[str,...],StoreMeta]
     def __init__(self, dataspace: DataSpaceType|None=None, namespace: tuple[str,...]=(), /):
@@ -240,9 +239,9 @@ class MemoryValueStore(SimpleValueStore[FridValue]):
     def _put(self, key: str, data: FridValue) -> bool:
         self._data[key] = data
         return True
-    def _rmw(self, key: str, mod: ModFunc[_E,_P],
+    def _rmw(self, key: str, mod: ModFunc[FridValue,_P],
              /, flags: VSPutFlag, *args: _P.args, **kwargs: _P.kwargs) -> bool:
-        old_data = self._data.get(key, MISSING)
+        old_data: FridValue|MissingType = self._data.get(key, MISSING)
         if flags & VSPutFlag.NO_CREATE:
             if old_data is MISSING:
                 return False
@@ -406,19 +405,19 @@ class BinaryStoreMixin:
         """
         out: list[bytes] = []
         for k, v in data.items():
-            line = escape_control_chars(k, '\x7f')
+            line = str_encode_nonprints(k, '\x7f')
             line += "\t" + (v.strfr() if isinstance(v, FridBeing) else dump_frid_str(v))
             out.append(line.encode())
         out.append(b'')
         return b'\n'.join(out)
     def _remove_dict(self, sel: VStoreSel, /) -> bytes:
         if isinstance(sel, str):
-            return (escape_control_chars(sel, '\x7f') + '\t' + MISSING.strfr()).encode()
+            return (str_encode_nonprints(sel, '\x7f') + '\t' + MISSING.strfr()).encode()
         assert isinstance(sel, Iterable)
         out: list[bytes] = []
         for k in sel:
             assert isinstance(k, str)
-            out.append((escape_control_chars(k, '\x7f') + '\t' + MISSING.strfr()).encode())
+            out.append((str_encode_nonprints(k, '\x7f') + '\t' + MISSING.strfr()).encode())
         out.append(b'')
         return b'\n'.join(out)
 
@@ -451,7 +450,7 @@ class BinaryStoreMixin:
         out = {}
         for line in val.splitlines():
             (key_str, tab_str, val_str) = line.decode().partition('\t')
-            key = revive_control_chars(key_str, '\x7f')
+            key = str_decode_nonprints(key_str, '\x7f')
             if tab_str:
                 being = FridBeing.parse(val_str)
                 if being is None:
