@@ -13,19 +13,19 @@ from sqlalchemy import types
 
 from ..typing import (
     MISSING, BlobTypes, DateTypes, FridArray, FridBeing,
-    FridTypeName, FridTypeSize, FridValue, MissingType, StrKeyMap
+    FridTypeName, FridTypeSize, FridValue, MissingType, StrKeyMap, frid_type_size, get_type_name
 )
 from ..guards import as_kv_pairs, is_frid_array, is_text_list_like
 from ..chrono import datetime, dateonly, timeonly
-from ..helper import frid_merge, frid_type_size, get_type_name
-from ..dumper import dump_frid_str
-from ..loader import load_frid_str
+from .._basic import frid_mingle
+from .._dumps import dump_frid_str
+from .._loads import load_frid_str
 from .store import AsyncStore, ValueStore
 from .utils import (
     BulkInput, KeySearch, VSPutFlag, VStoreKey, VStoreSel, is_dict_sel, is_list_sel,
     dict_concat, list_concat, frid_delete, frid_select, list_remove_all, list_select, match_key
 )
-from frid.kvs import utils
+from . import utils
 
 SqlTypes = str|float|int|DateTypes|bytes|bool  # Allowed data types for columns
 ParTypes = Mapping[str,FridValue]|Sequence[Mapping[str,FridValue]]|None
@@ -498,7 +498,7 @@ class _SqlBaseStore:
         assert len(datarows) == 1
         (row_key, data) = self._extract_row_value(datarows[0], None)
         assert row_key is None
-        val = frid_merge(data, val, depth=0)
+        val = frid_mingle(data, val, depth=0)
         return [self._make_update_cmd(key, val)]
     def _put_frid_insert(self, key: VStoreKey, val: FridValue, /, flags: VSPutFlag,
                          datarows: Sequence[Row]|None) -> list[Insert]:
